import Fuse from "fuse.js";
import { useState, useMemo } from "react";
import { useDebouncedCallback } from "use-debounce";
/** Searches icons
 * and sets the results to state
 * returns filtered and a debounced `searchCategoryIcons`
 */
function useSearchIcons(iconsMetadata, keys) {
    var searchIndex = useMemo(function () {
        return new Fuse(iconsMetadata, {
            keys: keys,
            threshold: 0.2,
        });
    }, [iconsMetadata, keys]);
    var _a = useState(iconsMetadata), filteredIconsMetadata = _a[0], setFilteredIconsMetadata = _a[1];
    // Debounced input callback
    var debouncedSearch = useDebouncedCallback(function (query) {
        if (!query) {
            // When query is empty reset to initial data
            setFilteredIconsMetadata(iconsMetadata);
        }
        else {
            var searchResults = searchIndex.search(query);
            var filteredIconsMetadata_1 = searchResults.map(function (_a) {
                var item = _a.item;
                return item;
            });
            setFilteredIconsMetadata(filteredIconsMetadata_1);
        }
    }, 300)[0];
    return { filteredIconsMetadata: filteredIconsMetadata, debouncedSearch: debouncedSearch };
}
export default useSearchIcons;
//# sourceMappingURL=useSearchIcons.js.map